==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-runner/translations/razor-runner_da_DK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="da_DK">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Razor-runner Settings</source>
        <translation>Programstarter Indstillinger</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Udseende</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Position:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Vis på:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="56"/>
        <source>Shortcut:</source>
        <translation>Genvej:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="70"/>
        <source>Top edge of screen</source>
        <translation>Skærmens topkant</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Center of screen</source>
        <translation>Skærmens midte</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="77"/>
        <source>Monitor where the mouse</source>
        <translation>Skærmen, hvor musen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="82"/>
        <source>Always on %1 monitor</source>
        <translation>Altid på skærm %1</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Programstarter</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="91"/>
        <source>Configure razor-runner</source>
        <translation>Indstil Razor programstarter</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="291"/>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation>Tryk &quot;%1&quot; for at se dialog.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="221"/>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="307"/>
        <source>Mathematics</source>
        <translation>Matematik</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-runner/translations/razor-runner_da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
<context>
    <name>ConfigureDialog</name>
    <message>
        <source>Razor-runner Settings</source>
        <translation>Programstarter Indstillinger</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Udseende</translation>
    </message>
    <message>
        <source>Positioning:</source>
        <translation>Position:</translation>
    </message>
    <message>
        <source>Show on:</source>
        <translation>Vis på:</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Genvej:</translation>
    </message>
    <message>
        <source>Top edge of screen</source>
        <translation>Skærmens topkant</translation>
    </message>
    <message>
        <source>Center of screen</source>
        <translation>Skærmens midte</translation>
    </message>
    <message>
        <source>Monitor where the mouse</source>
        <translation>Skærmen, hvor musen</translation>
    </message>
    <message>
        <source>Always on %1 monitor</source>
        <translation>Altid på skærm %1</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Application launcher </source>
        <translation>Programstarter</translation>
    </message>
    <message>
        <source>Configure razor-runner</source>
        <translation>Indstil Razor programstarter</translation>
    </message>
    <message>
        <source>Clear razor-runner History</source>
        <translation>Nulstil razor programstarter historik</translation>
    </message>
    <message>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation>Tryk &quot;%1&quot; for at se dialog.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>History</source>
        <translation>Historik</translation>
    </message>
    <message>
        <source>Mathematics</source>
        <translation>Matematik</translation>
    </message>
    <message>
        <source>Razor Power Management</source>
        <translation>Razor Strømstyring</translation>
    </message>
</context>
</TS>
